#!/usr/bin/env python3
#
# Parses and checks external VM IPs.

import json
from cmk.agent_based.v2 import Result, Service, State, CheckPlugin, AgentSection


def parse_triton_wedge(string_table):
    vms = []
    for row in string_table:
        vms.append(json.loads(row[0]))
    return vms


agent_section_triton_wedge = AgentSection(
    name="triton_wedge",
    parse_function=parse_triton_wedge
)


def discover_triton_wedge(section):
    if section:
        yield Service(item="1")


def check_triton_wedge(item, params, section):
    vms = section
    wedged_vms = []

    if len(vms) == 1 and vms[0].get("error"):
        yield Result(state=State.UNKNOWN, summary=vms[0]["error"])
        return

    for vm in vms:
        if vm["wedged"] == "probably":
            wedged_vms.append(vm)

    if len(wedged_vms) == 0:
        summary = f"No wedge detected ({len(vms)} VM external NIC(s) checked)"
        yield Result(state=State.OK, summary=summary)
    elif len(wedged_vms) == 1:
        vm = wedged_vms[0]
        summary = "Potential wedge detected for VM %s (%s)" % (vm["vm"], vm["ip"])
        yield Result(state=State.WARN, summary=summary)
    else:
        lst = ", ".join(map(lambda vm: "VM %s (%s)" % (vm["vm"], vm["ip"]), wedged_vms))
        yield Result(state=State.CRIT, summary=f"Likely wedge detected for {lst}") 


check_plugin_triton_wedge = CheckPlugin(
    name="triton_wedge",
    service_name="Triton Wedge Detector (%s)",
    discovery_function=discover_triton_wedge,
    check_function=check_triton_wedge,
    check_default_parameters={},
)
